Installation
============

.. Attention:: This page is currently under construction. The information displayed here may be incorrect

GTNet is available on the Python Package Index.

.. code:: bash

  pip install gtnet


It is also available through conda-forge.

.. code:: bash

  conda install -c conda-forge gtnet
